from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Geom import *
from OCC.Core.TopoDS import *
from OCC.Core.TopTools import *
from OCC.Core.BRepTools import *
from OCC.Core.Message import *
from OCC.Core.gp import *
from OCC.Core.TColStd import *
from OCC.Core.Bnd import *
from OCC.Core.Geom2d import *

#the following typedef cannot be wrapped as is
BRepBuilderAPI_BndBoxTree = NewType('BRepBuilderAPI_BndBoxTree', Any)
#the following typedef cannot be wrapped as is
BRepBuilderAPI_CellFilter = NewType('BRepBuilderAPI_CellFilter', Any)
#the following typedef cannot be wrapped as is
VectorOfPoint = NewType('VectorOfPoint', Any)

class BRepBuilderAPI_ShapeModification(IntEnum):
	BRepBuilderAPI_Preserved: int = ...
	BRepBuilderAPI_Deleted: int = ...
	BRepBuilderAPI_Trimmed: int = ...
	BRepBuilderAPI_Merged: int = ...
	BRepBuilderAPI_BoundaryModified: int = ...
BRepBuilderAPI_Preserved = BRepBuilderAPI_ShapeModification.BRepBuilderAPI_Preserved
BRepBuilderAPI_Deleted = BRepBuilderAPI_ShapeModification.BRepBuilderAPI_Deleted
BRepBuilderAPI_Trimmed = BRepBuilderAPI_ShapeModification.BRepBuilderAPI_Trimmed
BRepBuilderAPI_Merged = BRepBuilderAPI_ShapeModification.BRepBuilderAPI_Merged
BRepBuilderAPI_BoundaryModified = BRepBuilderAPI_ShapeModification.BRepBuilderAPI_BoundaryModified

class BRepBuilderAPI_WireError(IntEnum):
	BRepBuilderAPI_WireDone: int = ...
	BRepBuilderAPI_EmptyWire: int = ...
	BRepBuilderAPI_DisconnectedWire: int = ...
	BRepBuilderAPI_NonManifoldWire: int = ...
BRepBuilderAPI_WireDone = BRepBuilderAPI_WireError.BRepBuilderAPI_WireDone
BRepBuilderAPI_EmptyWire = BRepBuilderAPI_WireError.BRepBuilderAPI_EmptyWire
BRepBuilderAPI_DisconnectedWire = BRepBuilderAPI_WireError.BRepBuilderAPI_DisconnectedWire
BRepBuilderAPI_NonManifoldWire = BRepBuilderAPI_WireError.BRepBuilderAPI_NonManifoldWire

class BRepBuilderAPI_EdgeError(IntEnum):
	BRepBuilderAPI_EdgeDone: int = ...
	BRepBuilderAPI_PointProjectionFailed: int = ...
	BRepBuilderAPI_ParameterOutOfRange: int = ...
	BRepBuilderAPI_DifferentPointsOnClosedCurve: int = ...
	BRepBuilderAPI_PointWithInfiniteParameter: int = ...
	BRepBuilderAPI_DifferentsPointAndParameter: int = ...
	BRepBuilderAPI_LineThroughIdenticPoints: int = ...
BRepBuilderAPI_EdgeDone = BRepBuilderAPI_EdgeError.BRepBuilderAPI_EdgeDone
BRepBuilderAPI_PointProjectionFailed = BRepBuilderAPI_EdgeError.BRepBuilderAPI_PointProjectionFailed
BRepBuilderAPI_ParameterOutOfRange = BRepBuilderAPI_EdgeError.BRepBuilderAPI_ParameterOutOfRange
BRepBuilderAPI_DifferentPointsOnClosedCurve = BRepBuilderAPI_EdgeError.BRepBuilderAPI_DifferentPointsOnClosedCurve
BRepBuilderAPI_PointWithInfiniteParameter = BRepBuilderAPI_EdgeError.BRepBuilderAPI_PointWithInfiniteParameter
BRepBuilderAPI_DifferentsPointAndParameter = BRepBuilderAPI_EdgeError.BRepBuilderAPI_DifferentsPointAndParameter
BRepBuilderAPI_LineThroughIdenticPoints = BRepBuilderAPI_EdgeError.BRepBuilderAPI_LineThroughIdenticPoints

class BRepBuilderAPI_PipeError(IntEnum):
	BRepBuilderAPI_PipeDone: int = ...
	BRepBuilderAPI_PipeNotDone: int = ...
	BRepBuilderAPI_PlaneNotIntersectGuide: int = ...
	BRepBuilderAPI_ImpossibleContact: int = ...
BRepBuilderAPI_PipeDone = BRepBuilderAPI_PipeError.BRepBuilderAPI_PipeDone
BRepBuilderAPI_PipeNotDone = BRepBuilderAPI_PipeError.BRepBuilderAPI_PipeNotDone
BRepBuilderAPI_PlaneNotIntersectGuide = BRepBuilderAPI_PipeError.BRepBuilderAPI_PlaneNotIntersectGuide
BRepBuilderAPI_ImpossibleContact = BRepBuilderAPI_PipeError.BRepBuilderAPI_ImpossibleContact

class BRepBuilderAPI_TransitionMode(IntEnum):
	BRepBuilderAPI_Transformed: int = ...
	BRepBuilderAPI_RightCorner: int = ...
	BRepBuilderAPI_RoundCorner: int = ...
BRepBuilderAPI_Transformed = BRepBuilderAPI_TransitionMode.BRepBuilderAPI_Transformed
BRepBuilderAPI_RightCorner = BRepBuilderAPI_TransitionMode.BRepBuilderAPI_RightCorner
BRepBuilderAPI_RoundCorner = BRepBuilderAPI_TransitionMode.BRepBuilderAPI_RoundCorner

class BRepBuilderAPI_FaceError(IntEnum):
	BRepBuilderAPI_FaceDone: int = ...
	BRepBuilderAPI_NoFace: int = ...
	BRepBuilderAPI_NotPlanar: int = ...
	BRepBuilderAPI_CurveProjectionFailed: int = ...
	BRepBuilderAPI_ParametersOutOfRange: int = ...
BRepBuilderAPI_FaceDone = BRepBuilderAPI_FaceError.BRepBuilderAPI_FaceDone
BRepBuilderAPI_NoFace = BRepBuilderAPI_FaceError.BRepBuilderAPI_NoFace
BRepBuilderAPI_NotPlanar = BRepBuilderAPI_FaceError.BRepBuilderAPI_NotPlanar
BRepBuilderAPI_CurveProjectionFailed = BRepBuilderAPI_FaceError.BRepBuilderAPI_CurveProjectionFailed
BRepBuilderAPI_ParametersOutOfRange = BRepBuilderAPI_FaceError.BRepBuilderAPI_ParametersOutOfRange

class BRepBuilderAPI_ShellError(IntEnum):
	BRepBuilderAPI_ShellDone: int = ...
	BRepBuilderAPI_EmptyShell: int = ...
	BRepBuilderAPI_DisconnectedShell: int = ...
	BRepBuilderAPI_ShellParametersOutOfRange: int = ...
BRepBuilderAPI_ShellDone = BRepBuilderAPI_ShellError.BRepBuilderAPI_ShellDone
BRepBuilderAPI_EmptyShell = BRepBuilderAPI_ShellError.BRepBuilderAPI_EmptyShell
BRepBuilderAPI_DisconnectedShell = BRepBuilderAPI_ShellError.BRepBuilderAPI_DisconnectedShell
BRepBuilderAPI_ShellParametersOutOfRange = BRepBuilderAPI_ShellError.BRepBuilderAPI_ShellParametersOutOfRange

class brepbuilderapi:
	@overload
	@staticmethod
	def Plane(P: Geom_Plane) -> None: ...
	@overload
	@staticmethod
	def Plane() -> Geom_Plane: ...
	@overload
	@staticmethod
	def Precision(P: float) -> None: ...
	@overload
	@staticmethod
	def Precision() -> float: ...

class BRepBuilderAPI_Collect:
	def __init__(self) -> None: ...
	def Add(self, SI: TopoDS_Shape, MKS: BRepBuilderAPI_MakeShape) -> None: ...
	def AddGenerated(self, S: TopoDS_Shape, Gen: TopoDS_Shape) -> None: ...
	def AddModif(self, S: TopoDS_Shape, Mod: TopoDS_Shape) -> None: ...
	def Filter(self, SF: TopoDS_Shape) -> None: ...
	def Generated(self) -> TopTools_DataMapOfShapeListOfShape: ...
	def Modification(self) -> TopTools_DataMapOfShapeListOfShape: ...

class BRepBuilderAPI_Command:
	def Check(self) -> None: ...
	def IsDone(self) -> bool: ...

class BRepBuilderAPI_FastSewing(Standard_Transient):
	def __init__(self, theTolerance: Optional[float] = 1.0e-06) -> None: ...
	@overload
	def Add(self, theShape: TopoDS_Shape) -> bool: ...
	@overload
	def Add(self, theSurface: Geom_Surface) -> bool: ...
	def GetResult(self) -> TopoDS_Shape: ...
	def GetTolerance(self) -> float: ...
	def Perform(self) -> None: ...
	def SetTolerance(self, theToler: float) -> None: ...

class BRepBuilderAPI_FindPlane:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: TopoDS_Shape, Tol: Optional[float] = -1) -> None: ...
	def Found(self) -> bool: ...
	def Init(self, S: TopoDS_Shape, Tol: Optional[float] = -1) -> None: ...
	def Plane(self) -> Geom_Plane: ...

class BRepBuilderAPI_Sewing(Standard_Transient):
	def __init__(self, tolerance: Optional[float] = 1.0e-06, option1: Optional[bool] = True, option2: Optional[bool] = True, option3: Optional[bool] = True, option4: Optional[bool] = False) -> None: ...
	def Add(self, shape: TopoDS_Shape) -> None: ...
	def ContigousEdge(self, index: int) -> TopoDS_Edge: ...
	def ContigousEdgeCouple(self, index: int) -> TopTools_ListOfShape: ...
	def DegeneratedShape(self, index: int) -> TopoDS_Shape: ...
	def DeletedFace(self, index: int) -> TopoDS_Face: ...
	def Dump(self) -> None: ...
	def FaceMode(self) -> bool: ...
	def FloatingEdgesMode(self) -> bool: ...
	def FreeEdge(self, index: int) -> TopoDS_Edge: ...
	def GetContext(self) -> BRepTools_ReShape: ...
	def Init(self, tolerance: Optional[float] = 1.0e-06, option1: Optional[bool] = True, option2: Optional[bool] = True, option3: Optional[bool] = True, option4: Optional[bool] = False) -> None: ...
	def IsDegenerated(self, shape: TopoDS_Shape) -> bool: ...
	def IsModified(self, shape: TopoDS_Shape) -> bool: ...
	def IsModifiedSubShape(self, shape: TopoDS_Shape) -> bool: ...
	def IsSectionBound(self, section: TopoDS_Edge) -> bool: ...
	def Load(self, shape: TopoDS_Shape) -> None: ...
	def LocalTolerancesMode(self) -> bool: ...
	def MaxTolerance(self) -> float: ...
	def MinTolerance(self) -> float: ...
	def Modified(self, shape: TopoDS_Shape) -> TopoDS_Shape: ...
	def ModifiedSubShape(self, shape: TopoDS_Shape) -> TopoDS_Shape: ...
	def MultipleEdge(self, index: int) -> TopoDS_Edge: ...
	def NbContigousEdges(self) -> int: ...
	def NbDegeneratedShapes(self) -> int: ...
	def NbDeletedFaces(self) -> int: ...
	def NbFreeEdges(self) -> int: ...
	def NbMultipleEdges(self) -> int: ...
	def NonManifoldMode(self) -> bool: ...
	def Perform(self, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> None: ...
	def SameParameterMode(self) -> bool: ...
	def SectionToBoundary(self, section: TopoDS_Edge) -> TopoDS_Edge: ...
	def SetContext(self, theContext: BRepTools_ReShape) -> None: ...
	def SetFaceMode(self, theFaceMode: bool) -> None: ...
	def SetFloatingEdgesMode(self, theFloatingEdgesMode: bool) -> None: ...
	def SetLocalTolerancesMode(self, theLocalTolerancesMode: bool) -> None: ...
	def SetMaxTolerance(self, theMaxToler: float) -> None: ...
	def SetMinTolerance(self, theMinToler: float) -> None: ...
	def SetNonManifoldMode(self, theNonManifoldMode: bool) -> None: ...
	def SetSameParameterMode(self, SameParameterMode: bool) -> None: ...
	def SetTolerance(self, theToler: float) -> None: ...
	def SewedShape(self) -> TopoDS_Shape: ...
	def Tolerance(self) -> float: ...
	def WhichFace(self, theEdg: TopoDS_Edge, index: Optional[int] = 1) -> TopoDS_Face: ...

class BRepBuilderAPI_VertexInspector(NCollection_CellFilter_InspectorXYZ):
	def __init__(self, theTol: float) -> None: ...
	def Add(self, thePnt: gp_XYZ) -> None: ...
	def ClearResList(self) -> None: ...
	def Inspect(self, theTarget: int) -> NCollection_CellFilter_Action: ...
	def ResInd(self) -> TColStd_ListOfInteger: ...
	def SetCurrent(self, theCurPnt: gp_XYZ) -> None: ...

class BRepBuilderAPI_BndBoxTreeSelector():
	def __init__(self) -> None: ...
	def Accept(self, theObj: int) -> bool: ...
	def ClearResList(self) -> None: ...
	def Reject(self, theBox: Bnd_Box) -> bool: ...
	def ResInd(self) -> TColStd_ListOfInteger: ...
	def SetCurrent(self, theBox: Bnd_Box) -> None: ...

class BRepBuilderAPI_MakeShape(BRepBuilderAPI_Command):
	def Build(self) -> None: ...
	def Generated(self, S: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def IsDeleted(self, S: TopoDS_Shape) -> bool: ...
	def Modified(self, S: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def Shape(self) -> TopoDS_Shape: ...

class BRepBuilderAPI_MakeEdge(BRepBuilderAPI_MakeShape):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, P1: gp_Pnt, P2: gp_Pnt) -> None: ...
	@overload
	def __init__(self, L: gp_Lin) -> None: ...
	@overload
	def __init__(self, L: gp_Lin, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: gp_Lin, P1: gp_Pnt, P2: gp_Pnt) -> None: ...
	@overload
	def __init__(self, L: gp_Lin, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, L: gp_Circ) -> None: ...
	@overload
	def __init__(self, L: gp_Circ, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: gp_Circ, P1: gp_Pnt, P2: gp_Pnt) -> None: ...
	@overload
	def __init__(self, L: gp_Circ, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, L: gp_Elips) -> None: ...
	@overload
	def __init__(self, L: gp_Elips, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: gp_Elips, P1: gp_Pnt, P2: gp_Pnt) -> None: ...
	@overload
	def __init__(self, L: gp_Elips, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, L: gp_Hypr) -> None: ...
	@overload
	def __init__(self, L: gp_Hypr, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: gp_Hypr, P1: gp_Pnt, P2: gp_Pnt) -> None: ...
	@overload
	def __init__(self, L: gp_Hypr, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, L: gp_Parab) -> None: ...
	@overload
	def __init__(self, L: gp_Parab, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: gp_Parab, P1: gp_Pnt, P2: gp_Pnt) -> None: ...
	@overload
	def __init__(self, L: gp_Parab, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, L: Geom_Curve) -> None: ...
	@overload
	def __init__(self, L: Geom_Curve, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: Geom_Curve, P1: gp_Pnt, P2: gp_Pnt) -> None: ...
	@overload
	def __init__(self, L: Geom_Curve, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, L: Geom_Curve, P1: gp_Pnt, P2: gp_Pnt, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: Geom_Curve, V1: TopoDS_Vertex, V2: TopoDS_Vertex, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: Geom2d_Curve, S: Geom_Surface) -> None: ...
	@overload
	def __init__(self, L: Geom2d_Curve, S: Geom_Surface, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: Geom2d_Curve, S: Geom_Surface, P1: gp_Pnt, P2: gp_Pnt) -> None: ...
	@overload
	def __init__(self, L: Geom2d_Curve, S: Geom_Surface, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, L: Geom2d_Curve, S: Geom_Surface, P1: gp_Pnt, P2: gp_Pnt, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: Geom2d_Curve, S: Geom_Surface, V1: TopoDS_Vertex, V2: TopoDS_Vertex, p1: float, p2: float) -> None: ...
	def Edge(self) -> TopoDS_Edge: ...
	def Error(self) -> BRepBuilderAPI_EdgeError: ...
	@overload
	def Init(self, C: Geom_Curve) -> None: ...
	@overload
	def Init(self, C: Geom_Curve, p1: float, p2: float) -> None: ...
	@overload
	def Init(self, C: Geom_Curve, P1: gp_Pnt, P2: gp_Pnt) -> None: ...
	@overload
	def Init(self, C: Geom_Curve, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def Init(self, C: Geom_Curve, P1: gp_Pnt, P2: gp_Pnt, p1: float, p2: float) -> None: ...
	@overload
	def Init(self, C: Geom_Curve, V1: TopoDS_Vertex, V2: TopoDS_Vertex, p1: float, p2: float) -> None: ...
	@overload
	def Init(self, C: Geom2d_Curve, S: Geom_Surface) -> None: ...
	@overload
	def Init(self, C: Geom2d_Curve, S: Geom_Surface, p1: float, p2: float) -> None: ...
	@overload
	def Init(self, C: Geom2d_Curve, S: Geom_Surface, P1: gp_Pnt, P2: gp_Pnt) -> None: ...
	@overload
	def Init(self, C: Geom2d_Curve, S: Geom_Surface, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def Init(self, C: Geom2d_Curve, S: Geom_Surface, P1: gp_Pnt, P2: gp_Pnt, p1: float, p2: float) -> None: ...
	@overload
	def Init(self, C: Geom2d_Curve, S: Geom_Surface, V1: TopoDS_Vertex, V2: TopoDS_Vertex, p1: float, p2: float) -> None: ...
	def IsDone(self) -> bool: ...
	def Vertex1(self) -> TopoDS_Vertex: ...
	def Vertex2(self) -> TopoDS_Vertex: ...

class BRepBuilderAPI_MakeEdge2d(BRepBuilderAPI_MakeShape):
	@overload
	def __init__(self, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, P1: gp_Pnt2d, P2: gp_Pnt2d) -> None: ...
	@overload
	def __init__(self, L: gp_Lin2d) -> None: ...
	@overload
	def __init__(self, L: gp_Lin2d, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: gp_Lin2d, P1: gp_Pnt2d, P2: gp_Pnt2d) -> None: ...
	@overload
	def __init__(self, L: gp_Lin2d, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, L: gp_Circ2d) -> None: ...
	@overload
	def __init__(self, L: gp_Circ2d, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: gp_Circ2d, P1: gp_Pnt2d, P2: gp_Pnt2d) -> None: ...
	@overload
	def __init__(self, L: gp_Circ2d, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, L: gp_Elips2d) -> None: ...
	@overload
	def __init__(self, L: gp_Elips2d, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: gp_Elips2d, P1: gp_Pnt2d, P2: gp_Pnt2d) -> None: ...
	@overload
	def __init__(self, L: gp_Elips2d, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, L: gp_Hypr2d) -> None: ...
	@overload
	def __init__(self, L: gp_Hypr2d, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: gp_Hypr2d, P1: gp_Pnt2d, P2: gp_Pnt2d) -> None: ...
	@overload
	def __init__(self, L: gp_Hypr2d, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, L: gp_Parab2d) -> None: ...
	@overload
	def __init__(self, L: gp_Parab2d, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: gp_Parab2d, P1: gp_Pnt2d, P2: gp_Pnt2d) -> None: ...
	@overload
	def __init__(self, L: gp_Parab2d, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, L: Geom2d_Curve) -> None: ...
	@overload
	def __init__(self, L: Geom2d_Curve, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: Geom2d_Curve, P1: gp_Pnt2d, P2: gp_Pnt2d) -> None: ...
	@overload
	def __init__(self, L: Geom2d_Curve, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, L: Geom2d_Curve, P1: gp_Pnt2d, P2: gp_Pnt2d, p1: float, p2: float) -> None: ...
	@overload
	def __init__(self, L: Geom2d_Curve, V1: TopoDS_Vertex, V2: TopoDS_Vertex, p1: float, p2: float) -> None: ...
	def Edge(self) -> TopoDS_Edge: ...
	def Error(self) -> BRepBuilderAPI_EdgeError: ...
	@overload
	def Init(self, C: Geom2d_Curve) -> None: ...
	@overload
	def Init(self, C: Geom2d_Curve, p1: float, p2: float) -> None: ...
	@overload
	def Init(self, C: Geom2d_Curve, P1: gp_Pnt2d, P2: gp_Pnt2d) -> None: ...
	@overload
	def Init(self, C: Geom2d_Curve, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def Init(self, C: Geom2d_Curve, P1: gp_Pnt2d, P2: gp_Pnt2d, p1: float, p2: float) -> None: ...
	@overload
	def Init(self, C: Geom2d_Curve, V1: TopoDS_Vertex, V2: TopoDS_Vertex, p1: float, p2: float) -> None: ...
	def IsDone(self) -> bool: ...
	def Vertex1(self) -> TopoDS_Vertex: ...
	def Vertex2(self) -> TopoDS_Vertex: ...

class BRepBuilderAPI_MakeFace(BRepBuilderAPI_MakeShape):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, F: TopoDS_Face) -> None: ...
	@overload
	def __init__(self, P: gp_Pln) -> None: ...
	@overload
	def __init__(self, C: gp_Cylinder) -> None: ...
	@overload
	def __init__(self, C: gp_Cone) -> None: ...
	@overload
	def __init__(self, S: gp_Sphere) -> None: ...
	@overload
	def __init__(self, C: gp_Torus) -> None: ...
	@overload
	def __init__(self, S: Geom_Surface, TolDegen: float) -> None: ...
	@overload
	def __init__(self, P: gp_Pln, UMin: float, UMax: float, VMin: float, VMax: float) -> None: ...
	@overload
	def __init__(self, C: gp_Cylinder, UMin: float, UMax: float, VMin: float, VMax: float) -> None: ...
	@overload
	def __init__(self, C: gp_Cone, UMin: float, UMax: float, VMin: float, VMax: float) -> None: ...
	@overload
	def __init__(self, S: gp_Sphere, UMin: float, UMax: float, VMin: float, VMax: float) -> None: ...
	@overload
	def __init__(self, C: gp_Torus, UMin: float, UMax: float, VMin: float, VMax: float) -> None: ...
	@overload
	def __init__(self, S: Geom_Surface, UMin: float, UMax: float, VMin: float, VMax: float, TolDegen: float) -> None: ...
	@overload
	def __init__(self, W: TopoDS_Wire, OnlyPlane: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, P: gp_Pln, W: TopoDS_Wire, Inside: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, C: gp_Cylinder, W: TopoDS_Wire, Inside: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, C: gp_Cone, W: TopoDS_Wire, Inside: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, S: gp_Sphere, W: TopoDS_Wire, Inside: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, C: gp_Torus, W: TopoDS_Wire, Inside: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, S: Geom_Surface, W: TopoDS_Wire, Inside: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, F: TopoDS_Face, W: TopoDS_Wire) -> None: ...
	def Add(self, W: TopoDS_Wire) -> None: ...
	def Error(self) -> BRepBuilderAPI_FaceError: ...
	def Face(self) -> TopoDS_Face: ...
	@overload
	def Init(self, F: TopoDS_Face) -> None: ...
	@overload
	def Init(self, S: Geom_Surface, Bound: bool, TolDegen: float) -> None: ...
	@overload
	def Init(self, S: Geom_Surface, UMin: float, UMax: float, VMin: float, VMax: float, TolDegen: float) -> None: ...
	def IsDone(self) -> bool: ...

class BRepBuilderAPI_MakePolygon(BRepBuilderAPI_MakeShape):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, P1: gp_Pnt, P2: gp_Pnt) -> None: ...
	@overload
	def __init__(self, P1: gp_Pnt, P2: gp_Pnt, P3: gp_Pnt, Close: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, P1: gp_Pnt, P2: gp_Pnt, P3: gp_Pnt, P4: gp_Pnt, Close: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> None: ...
	@overload
	def __init__(self, V1: TopoDS_Vertex, V2: TopoDS_Vertex, V3: TopoDS_Vertex, Close: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, V1: TopoDS_Vertex, V2: TopoDS_Vertex, V3: TopoDS_Vertex, V4: TopoDS_Vertex, Close: Optional[bool] = False) -> None: ...
	@overload
	def Add(self, P: gp_Pnt) -> None: ...
	@overload
	def Add(self, V: TopoDS_Vertex) -> None: ...
	def Added(self) -> bool: ...
	def Close(self) -> None: ...
	def Edge(self) -> TopoDS_Edge: ...
	def FirstVertex(self) -> TopoDS_Vertex: ...
	def IsDone(self) -> bool: ...
	def LastVertex(self) -> TopoDS_Vertex: ...
	def Wire(self) -> TopoDS_Wire: ...

class BRepBuilderAPI_MakeShell(BRepBuilderAPI_MakeShape):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: Geom_Surface, Segment: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, S: Geom_Surface, UMin: float, UMax: float, VMin: float, VMax: float, Segment: Optional[bool] = False) -> None: ...
	def Error(self) -> BRepBuilderAPI_ShellError: ...
	def Init(self, S: Geom_Surface, UMin: float, UMax: float, VMin: float, VMax: float, Segment: Optional[bool] = False) -> None: ...
	def IsDone(self) -> bool: ...
	def Shell(self) -> TopoDS_Shell: ...

class BRepBuilderAPI_MakeSolid(BRepBuilderAPI_MakeShape):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: TopoDS_CompSolid) -> None: ...
	@overload
	def __init__(self, S: TopoDS_Shell) -> None: ...
	@overload
	def __init__(self, S1: TopoDS_Shell, S2: TopoDS_Shell) -> None: ...
	@overload
	def __init__(self, S1: TopoDS_Shell, S2: TopoDS_Shell, S3: TopoDS_Shell) -> None: ...
	@overload
	def __init__(self, So: TopoDS_Solid) -> None: ...
	@overload
	def __init__(self, So: TopoDS_Solid, S: TopoDS_Shell) -> None: ...
	def Add(self, S: TopoDS_Shell) -> None: ...
	def IsDeleted(self, S: TopoDS_Shape) -> bool: ...
	def IsDone(self) -> bool: ...
	def Solid(self) -> TopoDS_Solid: ...

class BRepBuilderAPI_MakeVertex(BRepBuilderAPI_MakeShape):
	@overload
	def __init__(self, P: gp_Pnt) -> None: ...
	def Vertex(self) -> TopoDS_Vertex: ...

class BRepBuilderAPI_MakeWire(BRepBuilderAPI_MakeShape):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, E: TopoDS_Edge) -> None: ...
	@overload
	def __init__(self, E1: TopoDS_Edge, E2: TopoDS_Edge) -> None: ...
	@overload
	def __init__(self, E1: TopoDS_Edge, E2: TopoDS_Edge, E3: TopoDS_Edge) -> None: ...
	@overload
	def __init__(self, E1: TopoDS_Edge, E2: TopoDS_Edge, E3: TopoDS_Edge, E4: TopoDS_Edge) -> None: ...
	@overload
	def __init__(self, W: TopoDS_Wire) -> None: ...
	@overload
	def __init__(self, W: TopoDS_Wire, E: TopoDS_Edge) -> None: ...
	@overload
	def Add(self, E: TopoDS_Edge) -> None: ...
	@overload
	def Add(self, W: TopoDS_Wire) -> None: ...
	@overload
	def Add(self, L: TopTools_ListOfShape) -> None: ...
	def Edge(self) -> TopoDS_Edge: ...
	def Error(self) -> BRepBuilderAPI_WireError: ...
	def IsDone(self) -> bool: ...
	def Vertex(self) -> TopoDS_Vertex: ...
	def Wire(self) -> TopoDS_Wire: ...

class BRepBuilderAPI_ModifyShape(BRepBuilderAPI_MakeShape):
	def Modified(self, S: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def ModifiedShape(self, S: TopoDS_Shape) -> TopoDS_Shape: ...

class BRepBuilderAPI_Copy(BRepBuilderAPI_ModifyShape):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: TopoDS_Shape, copyGeom: Optional[bool] = True, copyMesh: Optional[bool] = False) -> None: ...
	def Perform(self, S: TopoDS_Shape, copyGeom: Optional[bool] = True, copyMesh: Optional[bool] = False) -> None: ...

class BRepBuilderAPI_GTransform(BRepBuilderAPI_ModifyShape):
	@overload
	def __init__(self, T: gp_GTrsf) -> None: ...
	@overload
	def __init__(self, S: TopoDS_Shape, T: gp_GTrsf, Copy: Optional[bool] = False) -> None: ...
	def Modified(self, S: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def ModifiedShape(self, S: TopoDS_Shape) -> TopoDS_Shape: ...
	def Perform(self, S: TopoDS_Shape, Copy: Optional[bool] = False) -> None: ...

class BRepBuilderAPI_NurbsConvert(BRepBuilderAPI_ModifyShape):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: TopoDS_Shape, Copy: Optional[bool] = False) -> None: ...
	def Modified(self, S: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def ModifiedShape(self, S: TopoDS_Shape) -> TopoDS_Shape: ...
	def Perform(self, S: TopoDS_Shape, Copy: Optional[bool] = False) -> None: ...

class BRepBuilderAPI_Transform(BRepBuilderAPI_ModifyShape):
	@overload
	def __init__(self, T: gp_Trsf) -> None: ...
	@overload
	def __init__(self, S: TopoDS_Shape, T: gp_Trsf, Copy: Optional[bool] = False) -> None: ...
	def Modified(self, S: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def ModifiedShape(self, S: TopoDS_Shape) -> TopoDS_Shape: ...
	def Perform(self, S: TopoDS_Shape, Copy: Optional[bool] = False) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

brepbuilderapi_Plane = brepbuilderapi.Plane
brepbuilderapi_Plane = brepbuilderapi.Plane
brepbuilderapi_Precision = brepbuilderapi.Precision
brepbuilderapi_Precision = brepbuilderapi.Precision



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
IMeshTools module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_imeshtools.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _IMeshTools
else:
    import _IMeshTools

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _IMeshTools.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _IMeshTools.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _IMeshTools.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _IMeshTools.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _IMeshTools.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _IMeshTools.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _IMeshTools.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _IMeshTools.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _IMeshTools.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _IMeshTools.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _IMeshTools.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _IMeshTools.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _IMeshTools.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _IMeshTools.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _IMeshTools.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _IMeshTools.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _IMeshTools.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _IMeshTools:
_IMeshTools.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _IMeshTools.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.IMeshData
import OCC.Core.TopoDS
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.BRepAdaptor
import OCC.Core.Adaptor3d
import OCC.Core.Geom
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.Adaptor2d
import OCC.Core.Geom2d
import OCC.Core.math
import OCC.Core.GeomAdaptor
import OCC.Core.Geom2dAdaptor

from enum import IntEnum
from OCC.Core.Exception import *

IMeshTools_MeshAlgoType_DEFAULT = _IMeshTools.IMeshTools_MeshAlgoType_DEFAULT
IMeshTools_MeshAlgoType_Watson = _IMeshTools.IMeshTools_MeshAlgoType_Watson
IMeshTools_MeshAlgoType_Delabella = _IMeshTools.IMeshTools_MeshAlgoType_Delabella


class IMeshTools_MeshAlgoType(IntEnum):
	IMeshTools_MeshAlgoType_DEFAULT = - 1
	IMeshTools_MeshAlgoType_Watson = 0
	IMeshTools_MeshAlgoType_Delabella = 1
IMeshTools_MeshAlgoType_DEFAULT = IMeshTools_MeshAlgoType.IMeshTools_MeshAlgoType_DEFAULT
IMeshTools_MeshAlgoType_Watson = IMeshTools_MeshAlgoType.IMeshTools_MeshAlgoType_Watson
IMeshTools_MeshAlgoType_Delabella = IMeshTools_MeshAlgoType.IMeshTools_MeshAlgoType_Delabella


def Handle_IMeshTools_Context_Create() -> "opencascade::handle< IMeshTools_Context >":
    return _IMeshTools.Handle_IMeshTools_Context_Create()

def Handle_IMeshTools_Context_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< IMeshTools_Context >":
    return _IMeshTools.Handle_IMeshTools_Context_DownCast(t)

def Handle_IMeshTools_Context_IsNull(t: "opencascade::handle< IMeshTools_Context > const &") -> "bool":
    return _IMeshTools.Handle_IMeshTools_Context_IsNull(t)

def Handle_IMeshTools_CurveTessellator_Create() -> "opencascade::handle< IMeshTools_CurveTessellator >":
    return _IMeshTools.Handle_IMeshTools_CurveTessellator_Create()

def Handle_IMeshTools_CurveTessellator_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< IMeshTools_CurveTessellator >":
    return _IMeshTools.Handle_IMeshTools_CurveTessellator_DownCast(t)

def Handle_IMeshTools_CurveTessellator_IsNull(t: "opencascade::handle< IMeshTools_CurveTessellator > const &") -> "bool":
    return _IMeshTools.Handle_IMeshTools_CurveTessellator_IsNull(t)

def Handle_IMeshTools_MeshAlgo_Create() -> "opencascade::handle< IMeshTools_MeshAlgo >":
    return _IMeshTools.Handle_IMeshTools_MeshAlgo_Create()

def Handle_IMeshTools_MeshAlgo_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< IMeshTools_MeshAlgo >":
    return _IMeshTools.Handle_IMeshTools_MeshAlgo_DownCast(t)

def Handle_IMeshTools_MeshAlgo_IsNull(t: "opencascade::handle< IMeshTools_MeshAlgo > const &") -> "bool":
    return _IMeshTools.Handle_IMeshTools_MeshAlgo_IsNull(t)

def Handle_IMeshTools_MeshAlgoFactory_Create() -> "opencascade::handle< IMeshTools_MeshAlgoFactory >":
    return _IMeshTools.Handle_IMeshTools_MeshAlgoFactory_Create()

def Handle_IMeshTools_MeshAlgoFactory_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< IMeshTools_MeshAlgoFactory >":
    return _IMeshTools.Handle_IMeshTools_MeshAlgoFactory_DownCast(t)

def Handle_IMeshTools_MeshAlgoFactory_IsNull(t: "opencascade::handle< IMeshTools_MeshAlgoFactory > const &") -> "bool":
    return _IMeshTools.Handle_IMeshTools_MeshAlgoFactory_IsNull(t)

def Handle_IMeshTools_ModelAlgo_Create() -> "opencascade::handle< IMeshTools_ModelAlgo >":
    return _IMeshTools.Handle_IMeshTools_ModelAlgo_Create()

def Handle_IMeshTools_ModelAlgo_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< IMeshTools_ModelAlgo >":
    return _IMeshTools.Handle_IMeshTools_ModelAlgo_DownCast(t)

def Handle_IMeshTools_ModelAlgo_IsNull(t: "opencascade::handle< IMeshTools_ModelAlgo > const &") -> "bool":
    return _IMeshTools.Handle_IMeshTools_ModelAlgo_IsNull(t)

def Handle_IMeshTools_ShapeExplorer_Create() -> "opencascade::handle< IMeshTools_ShapeExplorer >":
    return _IMeshTools.Handle_IMeshTools_ShapeExplorer_Create()

def Handle_IMeshTools_ShapeExplorer_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< IMeshTools_ShapeExplorer >":
    return _IMeshTools.Handle_IMeshTools_ShapeExplorer_DownCast(t)

def Handle_IMeshTools_ShapeExplorer_IsNull(t: "opencascade::handle< IMeshTools_ShapeExplorer > const &") -> "bool":
    return _IMeshTools.Handle_IMeshTools_ShapeExplorer_IsNull(t)

def Handle_IMeshTools_ShapeVisitor_Create() -> "opencascade::handle< IMeshTools_ShapeVisitor >":
    return _IMeshTools.Handle_IMeshTools_ShapeVisitor_Create()

def Handle_IMeshTools_ShapeVisitor_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< IMeshTools_ShapeVisitor >":
    return _IMeshTools.Handle_IMeshTools_ShapeVisitor_DownCast(t)

def Handle_IMeshTools_ShapeVisitor_IsNull(t: "opencascade::handle< IMeshTools_ShapeVisitor > const &") -> "bool":
    return _IMeshTools.Handle_IMeshTools_ShapeVisitor_IsNull(t)
class IMeshTools_Context(OCC.Core.IMeshData.IMeshData_Shape):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructor.

        Returns
        -------
        None

        """
        _IMeshTools.IMeshTools_Context_swiginit(self, _IMeshTools.new_IMeshTools_Context(*args))

    def BuildModel(self, *args) -> "Standard_Boolean":
        r"""
        Builds model using assined model builder. returns true on success, false elsewhere.

        Returns
        -------
        bool

        """
        return _IMeshTools.IMeshTools_Context_BuildModel(self, *args)

    def ChangeParameters(self, *args) -> "IMeshTools_Parameters &":
        r"""
        Gets reference to parameters to be used for meshing.

        Returns
        -------
        IMeshTools_Parameters

        """
        return _IMeshTools.IMeshTools_Context_ChangeParameters(self, *args)

    def Clean(self, *args) -> "void":
        r"""
        Cleans temporary context data.

        Returns
        -------
        None

        """
        return _IMeshTools.IMeshTools_Context_Clean(self, *args)

    def DiscretizeEdges(self, *args) -> "Standard_Boolean":
        r"""
        Performs discretization of model edges using assigned edge discret algorithm. returns true on success, false elsewhere.

        Returns
        -------
        bool

        """
        return _IMeshTools.IMeshTools_Context_DiscretizeEdges(self, *args)

    def DiscretizeFaces(self, *args) -> "Standard_Boolean":
        r"""
        Performs meshing of faces of discrete model using assigned meshing algorithm. returns true on success, false elsewhere.

        Parameters
        ----------
        theRange: Message_ProgressRange

        Returns
        -------
        bool

        """
        return _IMeshTools.IMeshTools_Context_DiscretizeFaces(self, *args)

    def GetFaceDiscret(self, *args) -> "opencascade::handle< IMeshTools_ModelAlgo > const &":
        r"""
        Gets instance of meshing algorithm.

        Returns
        -------
        opencascade::handle<IMeshTools_ModelAlgo>

        """
        return _IMeshTools.IMeshTools_Context_GetFaceDiscret(self, *args)

    def GetModelHealer(self, *args) -> "opencascade::handle< IMeshTools_ModelAlgo > const &":
        r"""
        Gets instance of a tool to be used to heal discrete model.

        Returns
        -------
        opencascade::handle<IMeshTools_ModelAlgo>

        """
        return _IMeshTools.IMeshTools_Context_GetModelHealer(self, *args)

    def GetParameters(self, *args) -> "IMeshTools_Parameters const &":
        r"""
        Gets parameters to be used for meshing.

        Returns
        -------
        IMeshTools_Parameters

        """
        return _IMeshTools.IMeshTools_Context_GetParameters(self, *args)

    def GetPostProcessor(self, *args) -> "opencascade::handle< IMeshTools_ModelAlgo > const &":
        r"""
        Gets instance of post-processing algorithm.

        Returns
        -------
        opencascade::handle<IMeshTools_ModelAlgo>

        """
        return _IMeshTools.IMeshTools_Context_GetPostProcessor(self, *args)

    def GetPreProcessor(self, *args) -> "opencascade::handle< IMeshTools_ModelAlgo > const &":
        r"""
        Gets instance of pre-processing algorithm.

        Returns
        -------
        opencascade::handle<IMeshTools_ModelAlgo>

        """
        return _IMeshTools.IMeshTools_Context_GetPreProcessor(self, *args)

    def HealModel(self, *args) -> "Standard_Boolean":
        r"""
        Performs healing of discrete model built by discretizeedges() method using assigned healing algorithm. returns true on success, false elsewhere.

        Returns
        -------
        bool

        """
        return _IMeshTools.IMeshTools_Context_HealModel(self, *args)

    def PostProcessModel(self, *args) -> "Standard_Boolean":
        r"""
        Performs post-processing of discrete model using assigned algorithm. returns true on success, false elsewhere.

        Returns
        -------
        bool

        """
        return _IMeshTools.IMeshTools_Context_PostProcessModel(self, *args)

    def PreProcessModel(self, *args) -> "Standard_Boolean":
        r"""
        Performs pre-processing of discrete model using assigned algorithm. performs auxiliary actions such as cleaning shape from old triangulation. returns true on success, false elsewhere.

        Returns
        -------
        bool

        """
        return _IMeshTools.IMeshTools_Context_PreProcessModel(self, *args)

    def SetEdgeDiscret(self, *args) -> "void":
        r"""
        Sets instance of a tool to be used to discretize edges of a model.

        Parameters
        ----------
        theEdgeDiscret: Handle ( IMeshTools_ModelAlgo )

        Returns
        -------
        None

        """
        return _IMeshTools.IMeshTools_Context_SetEdgeDiscret(self, *args)

    def SetFaceDiscret(self, *args) -> "void":
        r"""
        Sets instance of meshing algorithm.

        Parameters
        ----------
        theFaceDiscret: IMeshTools_ModelAlgo

        Returns
        -------
        None

        """
        return _IMeshTools.IMeshTools_Context_SetFaceDiscret(self, *args)

    def SetModelBuilder(self, *args) -> "void":
        r"""
        Sets instance of a tool to be used to build discrete model.

        Parameters
        ----------
        theBuilder: Handle ( IMeshTools_ModelBuilder )

        Returns
        -------
        None

        """
        return _IMeshTools.IMeshTools_Context_SetModelBuilder(self, *args)

    def SetModelHealer(self, *args) -> "void":
        r"""
        Sets instance of a tool to be used to heal discrete model.

        Parameters
        ----------
        theModelHealer: IMeshTools_ModelAlgo

        Returns
        -------
        None

        """
        return _IMeshTools.IMeshTools_Context_SetModelHealer(self, *args)

    def SetPostProcessor(self, *args) -> "void":
        r"""
        Sets instance of post-processing algorithm.

        Parameters
        ----------
        thePostProcessor: IMeshTools_ModelAlgo

        Returns
        -------
        None

        """
        return _IMeshTools.IMeshTools_Context_SetPostProcessor(self, *args)

    def SetPreProcessor(self, *args) -> "void":
        r"""
        Sets instance of pre-processing algorithm.

        Parameters
        ----------
        thePreProcessor: IMeshTools_ModelAlgo

        Returns
        -------
        None

        """
        return _IMeshTools.IMeshTools_Context_SetPreProcessor(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_IMeshTools_Context_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _IMeshTools.delete_IMeshTools_Context

# Register IMeshTools_Context in _IMeshTools:
_IMeshTools.IMeshTools_Context_swigregister(IMeshTools_Context)

class IMeshTools_CurveTessellator(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def PointsNb(self, *args) -> "Standard_Integer":
        r"""
        Returns number of tessellation points.

        Returns
        -------
        int

        """
        return _IMeshTools.IMeshTools_CurveTessellator_PointsNb(self, *args)

    def Value(self, *args) -> "Standard_Boolean":
        r"""
        Returns parameters of solution with the given index. @param theindex index of tessellation point. @param thepoint tessellation point. @param theparameter parameters on pcurve corresponded to the solution. returns true in case of valid result, false elewhere.

        Parameters
        ----------
        theIndex: int
        thePoint: gp_Pnt

        Returns
        -------
        theParameter: float

        """
        return _IMeshTools.IMeshTools_CurveTessellator_Value(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_IMeshTools_CurveTessellator_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _IMeshTools.delete_IMeshTools_CurveTessellator

# Register IMeshTools_CurveTessellator in _IMeshTools:
_IMeshTools.IMeshTools_CurveTessellator_swigregister(IMeshTools_CurveTessellator)

class IMeshTools_MeshAlgo(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def Perform(self, *args) -> "void":
        r"""
        Performs processing of the given face.

        Parameters
        ----------
        theDFace: IMeshData::IFaceHandle
        theParameters: IMeshTools_Parameters
        theRange: Message_ProgressRange

        Returns
        -------
        None

        """
        return _IMeshTools.IMeshTools_MeshAlgo_Perform(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_IMeshTools_MeshAlgo_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _IMeshTools.delete_IMeshTools_MeshAlgo

# Register IMeshTools_MeshAlgo in _IMeshTools:
_IMeshTools.IMeshTools_MeshAlgo_swigregister(IMeshTools_MeshAlgo)

class IMeshTools_MeshAlgoFactory(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetAlgo(self, *args) -> "opencascade::handle< IMeshTools_MeshAlgo >":
        r"""
        Creates instance of meshing algorithm for the given type of surface.

        Parameters
        ----------
        theSurfaceType: GeomAbs_SurfaceType
        theParameters: IMeshTools_Parameters

        Returns
        -------
        opencascade::handle<IMeshTools_MeshAlgo>

        """
        return _IMeshTools.IMeshTools_MeshAlgoFactory_GetAlgo(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_IMeshTools_MeshAlgoFactory_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _IMeshTools.delete_IMeshTools_MeshAlgoFactory

# Register IMeshTools_MeshAlgoFactory in _IMeshTools:
_IMeshTools.IMeshTools_MeshAlgoFactory_swigregister(IMeshTools_MeshAlgoFactory)

class IMeshTools_MeshBuilder(OCC.Core.Message.Message_Algorithm):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructor.

        Returns
        -------
        None
        Constructor.

        Parameters
        ----------
        theContext: Handle ( IMeshTools_Context )

        Returns
        -------
        None

        """
        _IMeshTools.IMeshTools_MeshBuilder_swiginit(self, _IMeshTools.new_IMeshTools_MeshBuilder(*args))

    def Perform(self, *args) -> "void":
        r"""
        Performs meshing ot the shape using current context.

        Parameters
        ----------
        theRange: Message_ProgressRange

        Returns
        -------
        None

        """
        return _IMeshTools.IMeshTools_MeshBuilder_Perform(self, *args)

    def SetContext(self, *args) -> "void":
        r"""
        Sets context for algorithm.

        Parameters
        ----------
        theContext: Handle ( IMeshTools_Context )

        Returns
        -------
        None

        """
        return _IMeshTools.IMeshTools_MeshBuilder_SetContext(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IMeshTools.delete_IMeshTools_MeshBuilder

# Register IMeshTools_MeshBuilder in _IMeshTools:
_IMeshTools.IMeshTools_MeshBuilder_swigregister(IMeshTools_MeshBuilder)

class IMeshTools_ModelAlgo(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def Perform(self, *args) -> "Standard_Boolean":
        r"""
        Exceptions protected processing of the given model.

        Parameters
        ----------
        theModel: Handle ( IMeshData_Model )
        theParameters: IMeshTools_Parameters
        theRange: Message_ProgressRange

        Returns
        -------
        bool

        """
        return _IMeshTools.IMeshTools_ModelAlgo_Perform(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_IMeshTools_ModelAlgo_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _IMeshTools.delete_IMeshTools_ModelAlgo

# Register IMeshTools_ModelAlgo in _IMeshTools:
_IMeshTools.IMeshTools_ModelAlgo_swigregister(IMeshTools_ModelAlgo)

class IMeshTools_ModelBuilder(OCC.Core.Message.Message_Algorithm):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    __repr__ = _dumps_object

    __swig_destroy__ = _IMeshTools.delete_IMeshTools_ModelBuilder

# Register IMeshTools_ModelBuilder in _IMeshTools:
_IMeshTools.IMeshTools_ModelBuilder_swigregister(IMeshTools_ModelBuilder)

class IMeshTools_Parameters(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    MeshAlgo = property(_IMeshTools.IMeshTools_Parameters_MeshAlgo_get, _IMeshTools.IMeshTools_Parameters_MeshAlgo_set)
    Angle = property(_IMeshTools.IMeshTools_Parameters_Angle_get, _IMeshTools.IMeshTools_Parameters_Angle_set)
    Deflection = property(_IMeshTools.IMeshTools_Parameters_Deflection_get, _IMeshTools.IMeshTools_Parameters_Deflection_set)
    AngleInterior = property(_IMeshTools.IMeshTools_Parameters_AngleInterior_get, _IMeshTools.IMeshTools_Parameters_AngleInterior_set)
    DeflectionInterior = property(_IMeshTools.IMeshTools_Parameters_DeflectionInterior_get, _IMeshTools.IMeshTools_Parameters_DeflectionInterior_set)
    MinSize = property(_IMeshTools.IMeshTools_Parameters_MinSize_get, _IMeshTools.IMeshTools_Parameters_MinSize_set)
    InParallel = property(_IMeshTools.IMeshTools_Parameters_InParallel_get, _IMeshTools.IMeshTools_Parameters_InParallel_set)
    Relative = property(_IMeshTools.IMeshTools_Parameters_Relative_get, _IMeshTools.IMeshTools_Parameters_Relative_set)
    InternalVerticesMode = property(_IMeshTools.IMeshTools_Parameters_InternalVerticesMode_get, _IMeshTools.IMeshTools_Parameters_InternalVerticesMode_set)
    ControlSurfaceDeflection = property(_IMeshTools.IMeshTools_Parameters_ControlSurfaceDeflection_get, _IMeshTools.IMeshTools_Parameters_ControlSurfaceDeflection_set)
    CleanModel = property(_IMeshTools.IMeshTools_Parameters_CleanModel_get, _IMeshTools.IMeshTools_Parameters_CleanModel_set)
    AdjustMinSize = property(_IMeshTools.IMeshTools_Parameters_AdjustMinSize_get, _IMeshTools.IMeshTools_Parameters_AdjustMinSize_set)
    ForceFaceDeflection = property(_IMeshTools.IMeshTools_Parameters_ForceFaceDeflection_get, _IMeshTools.IMeshTools_Parameters_ForceFaceDeflection_set)
    AllowQualityDecrease = property(_IMeshTools.IMeshTools_Parameters_AllowQualityDecrease_get, _IMeshTools.IMeshTools_Parameters_AllowQualityDecrease_set)

    def __init__(self, *args):
        r"""
        Default constructor.

        Returns
        -------
        None

        """
        _IMeshTools.IMeshTools_Parameters_swiginit(self, _IMeshTools.new_IMeshTools_Parameters(*args))

    @staticmethod
    def RelMinSize(*args) -> "Standard_Real":
        r"""
        Returns factor used to compute default value of minsize (minimum mesh edge length) from deflection.

        Returns
        -------
        float

        """
        return _IMeshTools.IMeshTools_Parameters_RelMinSize(*args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IMeshTools.delete_IMeshTools_Parameters

# Register IMeshTools_Parameters in _IMeshTools:
_IMeshTools.IMeshTools_Parameters_swigregister(IMeshTools_Parameters)

def IMeshTools_Parameters_RelMinSize(*args) -> "Standard_Real":
    r"""
    Returns factor used to compute default value of minsize (minimum mesh edge length) from deflection.

    Returns
    -------
    float

    """
    return _IMeshTools.IMeshTools_Parameters_RelMinSize(*args)

class IMeshTools_ShapeExplorer(OCC.Core.IMeshData.IMeshData_Shape):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructor.

        Parameters
        ----------
        theShape: TopoDS_Shape

        Returns
        -------
        None

        """
        _IMeshTools.IMeshTools_ShapeExplorer_swiginit(self, _IMeshTools.new_IMeshTools_ShapeExplorer(*args))

    def Accept(self, *args) -> "void":
        r"""
        Starts exploring of a shape.

        Parameters
        ----------
        theVisitor: Handle ( IMeshTools_ShapeVisitor )

        Returns
        -------
        None

        """
        return _IMeshTools.IMeshTools_ShapeExplorer_Accept(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_IMeshTools_ShapeExplorer_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _IMeshTools.delete_IMeshTools_ShapeExplorer

# Register IMeshTools_ShapeExplorer in _IMeshTools:
_IMeshTools.IMeshTools_ShapeExplorer_swigregister(IMeshTools_ShapeExplorer)

class IMeshTools_ShapeVisitor(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def Visit(self, *args) -> "void":
        r"""
        Handles topods_face object.

        Parameters
        ----------
        theFace: TopoDS_Face

        Returns
        -------
        None
        Handles topods_edge object.

        Parameters
        ----------
        theEdge: TopoDS_Edge

        Returns
        -------
        None

        """
        return _IMeshTools.IMeshTools_ShapeVisitor_Visit(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_IMeshTools_ShapeVisitor_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _IMeshTools.delete_IMeshTools_ShapeVisitor

# Register IMeshTools_ShapeVisitor in _IMeshTools:
_IMeshTools.IMeshTools_ShapeVisitor_swigregister(IMeshTools_ShapeVisitor)








# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
RWStepAP214 module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_rwstepap214.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _RWStepAP214
else:
    import _RWStepAP214

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _RWStepAP214.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _RWStepAP214.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _RWStepAP214.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _RWStepAP214.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _RWStepAP214.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _RWStepAP214.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _RWStepAP214.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _RWStepAP214.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _RWStepAP214.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _RWStepAP214.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _RWStepAP214.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _RWStepAP214.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _RWStepAP214.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _RWStepAP214.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _RWStepAP214.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _RWStepAP214.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _RWStepAP214.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _RWStepAP214:
_RWStepAP214.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _RWStepAP214.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.StepData
import OCC.Core.Interface
import OCC.Core.TCollection
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.MoniTool
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.Resource
import OCC.Core.StepAP214
import OCC.Core.StepBasic
import OCC.Core.StepVisual
import OCC.Core.StepShape
import OCC.Core.StepGeom
import OCC.Core.StepRepr
import OCC.Core.TColgp

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_RWStepAP214_GeneralModule_Create() -> "opencascade::handle< RWStepAP214_GeneralModule >":
    return _RWStepAP214.Handle_RWStepAP214_GeneralModule_Create()

def Handle_RWStepAP214_GeneralModule_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< RWStepAP214_GeneralModule >":
    return _RWStepAP214.Handle_RWStepAP214_GeneralModule_DownCast(t)

def Handle_RWStepAP214_GeneralModule_IsNull(t: "opencascade::handle< RWStepAP214_GeneralModule > const &") -> "bool":
    return _RWStepAP214.Handle_RWStepAP214_GeneralModule_IsNull(t)

def Handle_RWStepAP214_ReadWriteModule_Create() -> "opencascade::handle< RWStepAP214_ReadWriteModule >":
    return _RWStepAP214.Handle_RWStepAP214_ReadWriteModule_Create()

def Handle_RWStepAP214_ReadWriteModule_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< RWStepAP214_ReadWriteModule >":
    return _RWStepAP214.Handle_RWStepAP214_ReadWriteModule_DownCast(t)

def Handle_RWStepAP214_ReadWriteModule_IsNull(t: "opencascade::handle< RWStepAP214_ReadWriteModule > const &") -> "bool":
    return _RWStepAP214.Handle_RWStepAP214_ReadWriteModule_IsNull(t)
class rwstepap214(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def Init(*args) -> "void":
        r"""
        Enforced the initialisation of the libraries.

        Returns
        -------
        None

        """
        return _RWStepAP214.rwstepap214_Init(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _RWStepAP214.rwstepap214_swiginit(self, _RWStepAP214.new_rwstepap214())
    __swig_destroy__ = _RWStepAP214.delete_rwstepap214

# Register rwstepap214 in _RWStepAP214:
_RWStepAP214.rwstepap214_swigregister(rwstepap214)

def rwstepap214_Init(*args) -> "void":
    r"""
    Enforced the initialisation of the libraries.

    Returns
    -------
    None

    """
    return _RWStepAP214.rwstepap214_Init(*args)

class RWStepAP214_GeneralModule(OCC.Core.StepData.StepData_GeneralModule):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a generalmodule.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_GeneralModule_swiginit(self, _RWStepAP214.new_RWStepAP214_GeneralModule(*args))


    @staticmethod
    def DownCast(t):
      return Handle_RWStepAP214_GeneralModule_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_GeneralModule

# Register RWStepAP214_GeneralModule in _RWStepAP214:
_RWStepAP214.RWStepAP214_GeneralModule_swigregister(RWStepAP214_GeneralModule)

class RWStepAP214_RWAppliedApprovalAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAppliedApprovalAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAppliedApprovalAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AppliedApprovalAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedApprovalAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AppliedApprovalAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedApprovalAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AppliedApprovalAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedApprovalAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAppliedApprovalAssignment

# Register RWStepAP214_RWAppliedApprovalAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAppliedApprovalAssignment_swigregister(RWStepAP214_RWAppliedApprovalAssignment)

class RWStepAP214_RWAppliedDateAndTimeAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAppliedDateAndTimeAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAppliedDateAndTimeAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AppliedDateAndTimeAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedDateAndTimeAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AppliedDateAndTimeAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedDateAndTimeAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AppliedDateAndTimeAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedDateAndTimeAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAppliedDateAndTimeAssignment

# Register RWStepAP214_RWAppliedDateAndTimeAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAppliedDateAndTimeAssignment_swigregister(RWStepAP214_RWAppliedDateAndTimeAssignment)

class RWStepAP214_RWAppliedDateAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAppliedDateAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAppliedDateAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AppliedDateAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedDateAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AppliedDateAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedDateAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AppliedDateAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedDateAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAppliedDateAssignment

# Register RWStepAP214_RWAppliedDateAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAppliedDateAssignment_swigregister(RWStepAP214_RWAppliedDateAssignment)

class RWStepAP214_RWAppliedDocumentReference(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAppliedDocumentReference_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAppliedDocumentReference(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AppliedDocumentReference

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedDocumentReference_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AppliedDocumentReference
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedDocumentReference_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AppliedDocumentReference

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedDocumentReference_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAppliedDocumentReference

# Register RWStepAP214_RWAppliedDocumentReference in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAppliedDocumentReference_swigregister(RWStepAP214_RWAppliedDocumentReference)

class RWStepAP214_RWAppliedExternalIdentificationAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAppliedExternalIdentificationAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAppliedExternalIdentificationAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads appliedexternalidentificationassignment.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AppliedExternalIdentificationAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedExternalIdentificationAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepAP214_AppliedExternalIdentificationAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedExternalIdentificationAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes appliedexternalidentificationassignment.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AppliedExternalIdentificationAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedExternalIdentificationAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAppliedExternalIdentificationAssignment

# Register RWStepAP214_RWAppliedExternalIdentificationAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAppliedExternalIdentificationAssignment_swigregister(RWStepAP214_RWAppliedExternalIdentificationAssignment)

class RWStepAP214_RWAppliedGroupAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAppliedGroupAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAppliedGroupAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads appliedgroupassignment.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AppliedGroupAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedGroupAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepAP214_AppliedGroupAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedGroupAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes appliedgroupassignment.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AppliedGroupAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedGroupAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAppliedGroupAssignment

# Register RWStepAP214_RWAppliedGroupAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAppliedGroupAssignment_swigregister(RWStepAP214_RWAppliedGroupAssignment)

class RWStepAP214_RWAppliedOrganizationAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAppliedOrganizationAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAppliedOrganizationAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AppliedOrganizationAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedOrganizationAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AppliedOrganizationAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedOrganizationAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AppliedOrganizationAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedOrganizationAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAppliedOrganizationAssignment

# Register RWStepAP214_RWAppliedOrganizationAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAppliedOrganizationAssignment_swigregister(RWStepAP214_RWAppliedOrganizationAssignment)

class RWStepAP214_RWAppliedPersonAndOrganizationAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAppliedPersonAndOrganizationAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAppliedPersonAndOrganizationAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AppliedPersonAndOrganizationAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedPersonAndOrganizationAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AppliedPersonAndOrganizationAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedPersonAndOrganizationAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AppliedPersonAndOrganizationAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedPersonAndOrganizationAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAppliedPersonAndOrganizationAssignment

# Register RWStepAP214_RWAppliedPersonAndOrganizationAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAppliedPersonAndOrganizationAssignment_swigregister(RWStepAP214_RWAppliedPersonAndOrganizationAssignment)

class RWStepAP214_RWAppliedPresentedItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAppliedPresentedItem_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAppliedPresentedItem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AppliedPresentedItem

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedPresentedItem_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AppliedPresentedItem
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedPresentedItem_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AppliedPresentedItem

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedPresentedItem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAppliedPresentedItem

# Register RWStepAP214_RWAppliedPresentedItem in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAppliedPresentedItem_swigregister(RWStepAP214_RWAppliedPresentedItem)

class RWStepAP214_RWAppliedSecurityClassificationAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAppliedSecurityClassificationAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAppliedSecurityClassificationAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AppliedSecurityClassificationAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedSecurityClassificationAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AppliedSecurityClassificationAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedSecurityClassificationAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AppliedSecurityClassificationAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAppliedSecurityClassificationAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAppliedSecurityClassificationAssignment

# Register RWStepAP214_RWAppliedSecurityClassificationAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAppliedSecurityClassificationAssignment_swigregister(RWStepAP214_RWAppliedSecurityClassificationAssignment)

class RWStepAP214_RWAutoDesignActualDateAndTimeAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAutoDesignActualDateAndTimeAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAutoDesignActualDateAndTimeAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AutoDesignActualDateAndTimeAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignActualDateAndTimeAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AutoDesignActualDateAndTimeAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignActualDateAndTimeAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AutoDesignActualDateAndTimeAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignActualDateAndTimeAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAutoDesignActualDateAndTimeAssignment

# Register RWStepAP214_RWAutoDesignActualDateAndTimeAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAutoDesignActualDateAndTimeAssignment_swigregister(RWStepAP214_RWAutoDesignActualDateAndTimeAssignment)

class RWStepAP214_RWAutoDesignActualDateAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAutoDesignActualDateAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAutoDesignActualDateAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AutoDesignActualDateAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignActualDateAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AutoDesignActualDateAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignActualDateAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AutoDesignActualDateAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignActualDateAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAutoDesignActualDateAssignment

# Register RWStepAP214_RWAutoDesignActualDateAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAutoDesignActualDateAssignment_swigregister(RWStepAP214_RWAutoDesignActualDateAssignment)

class RWStepAP214_RWAutoDesignApprovalAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAutoDesignApprovalAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAutoDesignApprovalAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AutoDesignApprovalAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignApprovalAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AutoDesignApprovalAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignApprovalAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AutoDesignApprovalAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignApprovalAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAutoDesignApprovalAssignment

# Register RWStepAP214_RWAutoDesignApprovalAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAutoDesignApprovalAssignment_swigregister(RWStepAP214_RWAutoDesignApprovalAssignment)

class RWStepAP214_RWAutoDesignDateAndPersonAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAutoDesignDateAndPersonAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAutoDesignDateAndPersonAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AutoDesignDateAndPersonAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignDateAndPersonAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AutoDesignDateAndPersonAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignDateAndPersonAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AutoDesignDateAndPersonAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignDateAndPersonAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAutoDesignDateAndPersonAssignment

# Register RWStepAP214_RWAutoDesignDateAndPersonAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAutoDesignDateAndPersonAssignment_swigregister(RWStepAP214_RWAutoDesignDateAndPersonAssignment)

class RWStepAP214_RWAutoDesignDocumentReference(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAutoDesignDocumentReference_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAutoDesignDocumentReference(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AutoDesignDocumentReference

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignDocumentReference_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AutoDesignDocumentReference
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignDocumentReference_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AutoDesignDocumentReference

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignDocumentReference_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAutoDesignDocumentReference

# Register RWStepAP214_RWAutoDesignDocumentReference in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAutoDesignDocumentReference_swigregister(RWStepAP214_RWAutoDesignDocumentReference)

class RWStepAP214_RWAutoDesignGroupAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAutoDesignGroupAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAutoDesignGroupAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AutoDesignGroupAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignGroupAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AutoDesignGroupAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignGroupAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AutoDesignGroupAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignGroupAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAutoDesignGroupAssignment

# Register RWStepAP214_RWAutoDesignGroupAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAutoDesignGroupAssignment_swigregister(RWStepAP214_RWAutoDesignGroupAssignment)

class RWStepAP214_RWAutoDesignNominalDateAndTimeAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAutoDesignNominalDateAndTimeAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAutoDesignNominalDateAndTimeAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AutoDesignNominalDateAndTimeAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignNominalDateAndTimeAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AutoDesignNominalDateAndTimeAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignNominalDateAndTimeAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AutoDesignNominalDateAndTimeAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignNominalDateAndTimeAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAutoDesignNominalDateAndTimeAssignment

# Register RWStepAP214_RWAutoDesignNominalDateAndTimeAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAutoDesignNominalDateAndTimeAssignment_swigregister(RWStepAP214_RWAutoDesignNominalDateAndTimeAssignment)

class RWStepAP214_RWAutoDesignNominalDateAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAutoDesignNominalDateAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAutoDesignNominalDateAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AutoDesignNominalDateAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignNominalDateAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AutoDesignNominalDateAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignNominalDateAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AutoDesignNominalDateAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignNominalDateAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAutoDesignNominalDateAssignment

# Register RWStepAP214_RWAutoDesignNominalDateAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAutoDesignNominalDateAssignment_swigregister(RWStepAP214_RWAutoDesignNominalDateAssignment)

class RWStepAP214_RWAutoDesignOrganizationAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAutoDesignOrganizationAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAutoDesignOrganizationAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AutoDesignOrganizationAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignOrganizationAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AutoDesignOrganizationAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignOrganizationAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AutoDesignOrganizationAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignOrganizationAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAutoDesignOrganizationAssignment

# Register RWStepAP214_RWAutoDesignOrganizationAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAutoDesignOrganizationAssignment_swigregister(RWStepAP214_RWAutoDesignOrganizationAssignment)

class RWStepAP214_RWAutoDesignPersonAndOrganizationAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAutoDesignPersonAndOrganizationAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAutoDesignPersonAndOrganizationAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AutoDesignPersonAndOrganizationAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignPersonAndOrganizationAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AutoDesignPersonAndOrganizationAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignPersonAndOrganizationAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AutoDesignPersonAndOrganizationAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignPersonAndOrganizationAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAutoDesignPersonAndOrganizationAssignment

# Register RWStepAP214_RWAutoDesignPersonAndOrganizationAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAutoDesignPersonAndOrganizationAssignment_swigregister(RWStepAP214_RWAutoDesignPersonAndOrganizationAssignment)

class RWStepAP214_RWAutoDesignPresentedItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAutoDesignPresentedItem_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAutoDesignPresentedItem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AutoDesignPresentedItem

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignPresentedItem_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AutoDesignPresentedItem
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignPresentedItem_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AutoDesignPresentedItem

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignPresentedItem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAutoDesignPresentedItem

# Register RWStepAP214_RWAutoDesignPresentedItem in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAutoDesignPresentedItem_swigregister(RWStepAP214_RWAutoDesignPresentedItem)

class RWStepAP214_RWAutoDesignSecurityClassificationAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWAutoDesignSecurityClassificationAssignment_swiginit(self, _RWStepAP214.new_RWStepAP214_RWAutoDesignSecurityClassificationAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_AutoDesignSecurityClassificationAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignSecurityClassificationAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP214_AutoDesignSecurityClassificationAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignSecurityClassificationAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_AutoDesignSecurityClassificationAssignment

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWAutoDesignSecurityClassificationAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWAutoDesignSecurityClassificationAssignment

# Register RWStepAP214_RWAutoDesignSecurityClassificationAssignment in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWAutoDesignSecurityClassificationAssignment_swigregister(RWStepAP214_RWAutoDesignSecurityClassificationAssignment)

class RWStepAP214_RWClass(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWClass_swiginit(self, _RWStepAP214.new_RWStepAP214_RWClass(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads class.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_Class

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWClass_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepAP214_Class
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWClass_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes class.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_Class

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWClass_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWClass

# Register RWStepAP214_RWClass in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWClass_swigregister(RWStepAP214_RWClass)

class RWStepAP214_RWExternallyDefinedClass(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWExternallyDefinedClass_swiginit(self, _RWStepAP214.new_RWStepAP214_RWExternallyDefinedClass(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads externallydefinedclass.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_ExternallyDefinedClass

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWExternallyDefinedClass_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepAP214_ExternallyDefinedClass
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWExternallyDefinedClass_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes externallydefinedclass.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_ExternallyDefinedClass

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWExternallyDefinedClass_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWExternallyDefinedClass

# Register RWStepAP214_RWExternallyDefinedClass in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWExternallyDefinedClass_swigregister(RWStepAP214_RWExternallyDefinedClass)

class RWStepAP214_RWExternallyDefinedGeneralProperty(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWExternallyDefinedGeneralProperty_swiginit(self, _RWStepAP214.new_RWStepAP214_RWExternallyDefinedGeneralProperty(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads externallydefinedgeneralproperty.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_ExternallyDefinedGeneralProperty

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWExternallyDefinedGeneralProperty_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepAP214_ExternallyDefinedGeneralProperty
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWExternallyDefinedGeneralProperty_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes externallydefinedgeneralproperty.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_ExternallyDefinedGeneralProperty

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWExternallyDefinedGeneralProperty_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWExternallyDefinedGeneralProperty

# Register RWStepAP214_RWExternallyDefinedGeneralProperty in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWExternallyDefinedGeneralProperty_swigregister(RWStepAP214_RWExternallyDefinedGeneralProperty)

class RWStepAP214_RWRepItemGroup(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_RWRepItemGroup_swiginit(self, _RWStepAP214.new_RWStepAP214_RWRepItemGroup(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads repitemgroup.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP214_RepItemGroup

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWRepItemGroup_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepAP214_RepItemGroup
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWRepItemGroup_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes repitemgroup.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP214_RepItemGroup

        Returns
        -------
        None

        """
        return _RWStepAP214.RWStepAP214_RWRepItemGroup_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_RWRepItemGroup

# Register RWStepAP214_RWRepItemGroup in _RWStepAP214:
_RWStepAP214.RWStepAP214_RWRepItemGroup_swigregister(RWStepAP214_RWRepItemGroup)

class RWStepAP214_ReadWriteModule(OCC.Core.StepData.StepData_ReadWriteModule):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP214.RWStepAP214_ReadWriteModule_swiginit(self, _RWStepAP214.new_RWStepAP214_ReadWriteModule(*args))

    def CaseStep(self, *args) -> "Standard_Integer":
        r"""
        Associates a positive case number to each type of stepap214 entity, given as a string defined in the express form.

        Parameters
        ----------
        atype: TCollection_AsciiString

        Returns
        -------
        int
        Associates a positive case number to each type of stepap214 complex entity, given as a string defined in the express form.

        Parameters
        ----------
        types: TColStd_SequenceOfAsciiString

        Returns
        -------
        int

        """
        return _RWStepAP214.RWStepAP214_ReadWriteModule_CaseStep(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_RWStepAP214_ReadWriteModule_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP214.delete_RWStepAP214_ReadWriteModule

# Register RWStepAP214_ReadWriteModule in _RWStepAP214:
_RWStepAP214.RWStepAP214_ReadWriteModule_swigregister(RWStepAP214_ReadWriteModule)





